@@ -399,13 +399,11 @@ class RenewFiscalYear(metaclass=PoolMeta):
                 sequence = getattr(invoice_sequence, field, None)
                 sequences[sequence.id] = sequence
         copies = Sequence.copy(list(sequences.values()), default={
+                'next_number': 1,
                 'name': lambda data: data['name'].replace(
                     self.start.previous_fiscalyear.name,
                     self.start.name)
                 })
-        Sequence.write(copies, {
-                'number_next': Sequence.default_number_next(),
-                })
 
         mapping = {}
         for previous_id, new_sequence in zip(sequences.keys(), copies):
@@ -442,3 +440,24 @@ class RescheduleLines(metaclass=PoolMeta):
                 'additional_moves': [('add', [move.id])],
                 })
         return move, balance_line
+
+
+class DelegateLines(metaclass=PoolMeta):
+    __name__ = 'account.move.line.delegate'
+
+    @classmethod
+    def delegate_lines(cls, lines, party, journal, date=None):
+        pool = Pool()
+        Invoice = pool.get('account.invoice')
+        move = super().delegate_lines(lines, party, journal, date=None)
+
+        move_ids = list({l.move.id for l in lines})
+        invoices = Invoice.search(['OR',
+                ('move', 'in', move_ids),
+                ('additional_moves', 'in', move_ids),
+                ])
+        Invoice.write(invoices, {
+                'alternative_payees': [('add', [party.id])],
+                'additional_moves': [('add', [move.id])],
+                })
+        return move
